@@ -1,12 +1,8 @@
-"""Entity base class and metaclass.
+"""Entity base class.
 
 The :class:`Entity` class here should be used as the base class for any and
 all entity classes, regardless of what database the entities are derived from.
 
-Ditto for the :class:`EntityMeta` class, which should be used as the basis
-for all SQLAlchemy declarative entities (which will probably be *all*
-entities).
-
 """
 import datetime
 import decimal
@@ -52,7 +48,10 @@ class Entity(object):
     @property
     def id_str(self):
         """Convert `id` from Python to string."""
-        id = json.dumps(self.simplify_object(self.id))
+        if isinstance(self.id, basestring):
+            id = self.id
+        else:
+            id = json.dumps(self.simplify_object(self.id))
         return id
 
     @classmethod
@@ -80,6 +79,10 @@ class Entity(object):
             cls._has_multipart_primary_key = (True if (len(pk) > 1) else False)
         return cls._has_multipart_primary_key
 
+    @classmethod
+    def convert_param(self, name, val):
+        return val
+
     @classmethod
     def simplify_object(cls, obj, name=None):
         """Convert ``obj`` to something JSON encoder can handle."""
@@ -105,7 +108,10 @@ class Entity(object):
         this arg isn't given, ``self.public_names`` is used instead.
 
         """
-        obj = dict(type=self.__class__.__name__)
+        obj = dict(
+            __module__=self.__class__.__module__,
+            __type__=self.__class__.__name__,
+        )
         if fields is None:
             fields = [(f, f) for f in self.public_names]
         for name, as_name in fields:
@@ -116,7 +122,7 @@ class Entity(object):
             val = self.simplify_object(o, n)
             if name == as_name:
                 # If `name` has only one part, this sets obj[name] = val.
-                # If `name` had more than N parts, this sets
+                # If `name` has more than one part (N parts), this sets
                 # obj[name1][name2][...][nameN] = val.
                 slot = obj
                 for n in name_parts[:-1]:
@@ -151,11 +157,6 @@ class Entity(object):
         simple_obj = cls.to_simple_collection(collection, fields=fields)
         return json.dumps(simple_obj)
 
-    def get_column_default(self, key):
-        """Get default set in SQLA table (NOT server default)."""
-        default = self.__table__.columns.get(key).default.arg
-        return default
-
     @property
     def public_names(self):
         """We want all public DB columns and `property`s by default."""
@@ -190,13 +191,18 @@ class Entity(object):
         return '\n'.join(string)
 
 
-def instrument_class(cls):
+def instrument_class(cls, mixin=Entity):
     """Add member/collection class attributes to `Entity` subclass ``cls``.
 
     ``cls`` will be instrumented with ``member_name``, ``collection_name``,
     ``member_title``, and ``collection_title`` class attributes, IFF these
     class attributes are not already set in the class definition.
 
+    In addition, ``mixin`` will be dynamically inserted into ``cls``'s
+    list of base classes. ``mixin`` must be :class:`Entity` or a subclass
+    (although this isn't currently enforced). ``mixin`` can also be `None`
+    to completely disable this "feature" (XXX: Should this be the default?).
+
     """
     if not hasattr(cls, 'member_name'):
         cls.member_name = camel_to_underscore(cls.__name__)
@@ -206,16 +212,6 @@ def instrument_class(cls):
         cls.member_title = underscore_to_title(cls.member_name)
     if not hasattr(cls, 'collection_title'):
         cls.collection_title = underscore_to_title(cls.collection_name)
-
-
-class EntityMeta(type):
-    """Deprecated. Use :func:`instrument_class` instead."""
-
-    def __init__(cls, name, bases, attrs):
-        import warnings
-        warnings.warn(
-            'The EntityMeta metaclass is deprecated. '
-            'Use the restler.entity.instrument_class function instead.',
-            DeprecationWarning, 2)
-        type.__init__(cls, name, bases, attrs)
-        instrument_class(cls)
+    if mixin is not None and mixin not in cls.__bases__:
+            cls.__bases__ += (mixin,)
+    return cls
